package edu.byu.cs240.bookclub.database;

import android.database.sqlite.SQLiteDatabase;
import android.test.AndroidTestCase;

import java.util.Set;

import edu.byu.cs240.bookclub.model.Book;
import edu.byu.cs240.bookclub.model.Genre;

public class BookDAOTest extends AndroidTestCase {

    private static final String TAG = "BookDAOTest";

    private DbOpenHelper dbOpenHelper;
    private SQLiteDatabase db;
    private BookDAO dao;

    @Override
    public void setUp() throws Exception {
        super.setUp();

        dbOpenHelper = new DbOpenHelper(getContext());

        db = dbOpenHelper.getWritableDatabase();
        db.beginTransaction();

        dao = new BookDAO(db);
    }


    @Override
    public void tearDown() throws Exception {
        super.tearDown();

        db.endTransaction();
        db = null;

        dbOpenHelper.close();
        dbOpenHelper = null;
    }

    public void testAll() {
        Book book = new Book();
        book.setTitle("Killing Reagan");
        book.setAuthor("Bill O'Reilly");
        book.setGenre(Genre.NonFiction);

        assertEquals(-1, book.getID());
        assertTrue(dao.addBook(book));
        assertTrue(book.getID() >= 0);

        Set<Book> set = dao.getBooksByAuthor("Bill O'Reilly");
        assertEquals(1, set.size());
        Book copy = set.iterator().next();
        assertEquals(book.getID(), copy.getID());
        assertEquals(book.getTitle(), copy.getTitle());
        assertEquals(book.getAuthor(), copy.getAuthor());
        assertEquals(book.getGenre(), copy.getGenre());

        Book book2 = new Book();
        book2.setTitle("Killing Lincoln");
        book2.setAuthor("Martin Dugard");
        book2.setGenre(Genre.NonFiction);

        assertEquals(-1, book2.getID());
        assertTrue(dao.addBook(book2));
        assertTrue(book2.getID() >= 0);

        set = dao.getBooksByAuthor("Bill O'Reilly");
        assertEquals(1, set.size());

        book2.setAuthor("Bill O'Reilly");
        assertTrue(dao.updateBook(book2));
        set = dao.getBooksByAuthor("Bill O'Reilly");
        assertEquals(2, set.size());
/*
        assertTrue(dao.deleteBook(book));
        assertEquals(-1, book.getID());
        set = dao.getBooksByAuthor("Bill O'Reilly");
        assertEquals(1, set.size());

        assertTrue(dao.deleteBook(book2));
        assertEquals(-1, book2.getID());
        set = dao.getBooksByAuthor("Bill O'Reilly");
        assertEquals(0, set.size());
    */
    }

}
